@@ -296,12 +296,13 @@ LOCKED_DIRECTORY = "locked"
 # global variables
 #
 
-__FileRegexp = "[0-9a-zA-Z]+"
-_FileRegexp = re.compile("^(%s)$" % __FileRegexp)
-_KeyValRegexp = re.compile('^([^\x09\x0a]*)\x09([^\x09\x0a]*)$')
+_FileRegexp = re.compile("^([0-9a-zA-Z]+)$")
+_KeyValRegexp = re.compile("^([^\x09\x0a]*)\x09([^\x09\x0a]*)$")
+_H2SRegexp = re.compile("(\\\\|\x09|\x0a)")
+_S2HRegexp = re.compile(r"(\\\\|\\t|\\n)")
 
 _Byte2Esc = {"\\": r"\\", "\t": r"\t", "\n": r"\n"}
-_Esc2Byte = dict([(value, key) for key, value in _Byte2Esc.items()])
+_Esc2Byte = dict([(_value, _key) for _key, _value in _Byte2Esc.items()])
 
 #
 # Helper Functions
@@ -323,8 +324,8 @@ def _hash2string(data):
         val = data[key]
         if type(val) not in VALID_STR_TYPES:
             raise QueueError("invalid hash value type: %r" % val)
-        key = re.sub('(\\\\|\x09|\x0a)', lambda m: _Byte2Esc[m.group(1)], key)
-        val = re.sub('(\\\\|\x09|\x0a)', lambda m: _Byte2Esc[m.group(1)], val)
+        key = _H2SRegexp.sub(lambda m: _Byte2Esc[m.group(1)], key)
+        val = _H2SRegexp.sub(lambda m: _Byte2Esc[m.group(1)], val)
         string = '%s%s' % (string, '%s\x09%s\x0a' % (key, val))
     return string
 
@@ -345,10 +346,10 @@ def _string2hash(given):
         match = _KeyValRegexp.match(line)
         if not match:
             raise QueueError("unexpected hash line: %s" % line)
-        key = re.sub(r'(\\\\|\\t|\\n)', lambda m: _Esc2Byte[str(m.group(1))],
-                     match.group(1))
-        val = re.sub(r'(\\\\|\\t|\\n)', lambda m: _Esc2Byte[str(m.group(1))],
-                     match.group(2))
+        key = _S2HRegexp.sub(lambda m: _Esc2Byte[str(m.group(1))],
+                             match.group(1))
+        val = _S2HRegexp.sub(lambda m: _Esc2Byte[str(m.group(1))],
+                             match.group(2))
         _hash[key] = val
     return _hash
 
@@ -453,7 +454,8 @@ def _count(path):
 class Queue(QueueBase):
     """Directory based queue.
     """
-    def __init__(self, path, umask=None, maxelts=16000, schema=dict()):
+    def __init__(self, path, umask=None, rndhex=None, maxelts=16000,
+                 schema=dict()):
         """Check and set schema. Build the queue directory structure.
 
         Arguments:
@@ -462,6 +464,9 @@ class Queue(QueueBase):
             umask
                 the umask to use when creating files and directories
                 (default: use the running process' umask)
+            rndhex
+                the hexadecimal digit to use in names
+                (default: randomly chosen)
             maxelts
                 the maximum number of elements that an intermediate
                 directory can hold (default: 16,000)
@@ -473,7 +478,7 @@ class Queue(QueueBase):
             QueueError - problems with the queue schema definition
             OSError    - can't create directory structure
         """
-        super(Queue, self).__init__(path, umask=umask)
+        super(Queue, self).__init__(path, umask=umask, rndhex=rndhex)
 
         if type(maxelts) in VALID_INT_TYPES:
             self.maxelts = maxelts
@@ -491,13 +496,13 @@ class Queue(QueueBase):
                 if not isinstance(schema[name], str):
                     raise QueueError("invalid data type for schema " +
                                      "specification: %r" % type(schema[name]))
-                match = re.match('(binary|string|table)([\?\*]{0,2})?$',
+                match = re.match('(binary|string|table)([\\?\\*]{0,2})?$',
                                  schema[name])
                 if not match:
                     raise QueueError("invalid schema data type: %r" %
                                      schema[name])
                 self.type[name] = match.group(1)
-                if not re.search('\?', match.group(2)):
+                if not re.search('\\?', match.group(2)):
                     self.mandatory[name] = True
             if not self.mandatory:
                 raise QueueError("invalid schema: no mandatory data")
@@ -723,7 +728,8 @@ class Queue(QueueBase):
         # move the element out of its intermediate directory
         path = '%s/%s' % (self.path, ename)
         while True:
-            temp = '%s/%s/%s' % (self.path, OBSOLETE_DIRECTORY, _name())
+            temp = '%s/%s/%s' % (self.path, OBSOLETE_DIRECTORY,
+                                 _name(self.rndhex))
             try:
                 os.rename(path, temp)
                 break
@@ -909,7 +915,8 @@ class Queue(QueueBase):
         if not self.type:
             raise QueueError("unknown schema")
         while True:
-            temp = '%s/%s/%s' % (self.path, TEMPORARY_DIRECTORY, _name())
+            temp = '%s/%s/%s' % (self.path, TEMPORARY_DIRECTORY,
+                                 _name(self.rndhex))
             if _special_mkdir(temp, self.umask):
                 break
         for name in data.keys():
@@ -938,7 +945,7 @@ class Queue(QueueBase):
             if name not in data:
                 raise QueueError("missing mandatory data: %s" % name)
         while True:
-            name = '%s/%s' % (self._insertion_directory(), _name())
+            name = '%s/%s' % (self._insertion_directory(), _name(self.rndhex))
             path = '%s/%s' % (self.path, name)
             try:
                 os.rename(temp, path)
@@ -1025,8 +1032,6 @@ class Queue(QueueBase):
             name = self.first()
             while name:
                 if self._is_locked(name, oldtime):
-                    # TODO: check if remove_element is needed or
-                    # "unlocking" instead.
                     _warn("* removing too old locked element: %s" % name)
                     self.unlock(name, True)
                 name = self.next()
